---
name: Parameter Submission
about: Submit parameters to polyply library.
title: "[PARAMETERS]"
labels: parameter submission
assignees: ''

---

**Parameter Description**
A brief description of the parameters you want to add to the library providing the following information:
- residue/monomer name
- citation if available
- force-field
- simulation program (currently only GROMACS is supported)
- are the termini different? 

** Additional Files & Resources** 
If you want us to implement the parameters please provide the following files. However, we encourage users to try implementing files themselves by opening a PR. 

- reference itp file
- link to force-field definition if it is a new force-field not part of the library 
